@@ -36,7 +36,7 @@ constexpr unsigned API_VERSION_2_2 = ZIMG_MAKE_API_VERSION(2, 2);
 thread_local zimg_error_code_e g_last_error = ZIMG_ERROR_SUCCESS;
 thread_local std::string g_last_error_msg;
 
-constexpr unsigned VERSION_INFO[] = { 2, 8, 0 };
+constexpr unsigned VERSION_INFO[] = { 2, 9, 2 };
 
 
 template <class T, class U>
@@ -68,7 +68,7 @@ zimg_error_code_e handle_exception(std::exception_ptr eptr) noexcept
 	zimg_error_code_e code = ZIMG_ERROR_UNKNOWN;
 
 #define CATCH(type, error_code) catch (const type &e) { record_exception_message(e); code = (error_code); }
-#define FATAL(type, error_code, msg) catch (const type &e) { record_exception_message(e); code = (error_code); zassert_d(false, msg); }
+#define FATAL(type, error_code, msg) catch (const type &e) { record_exception_message(e); code = (error_code); zassert_dfatal(msg); }
 	try {
 		std::rethrow_exception(eptr);
 	}
@@ -96,7 +96,7 @@ zimg_error_code_e handle_exception(std::exception_ptr eptr) noexcept
 	FATAL(Exception,               ZIMG_ERROR_UNKNOWN, "unregistered error generated")
 	catch (...) {
 		g_last_error_msg[0] = '\0';
-		zassert_d(false, "bad exception type");
+		zassert_dfatal("bad exception type");
 	}
 #undef CATCH
 #undef FATAL
@@ -145,7 +145,7 @@ zimg::CPUClass translate_cpu(zimg_cpu_type_e cpu)
 		{ ZIMG_CPU_X86_F16C,       CPUClass::X86_F16C },
 		{ ZIMG_CPU_X86_AVX2,       CPUClass::X86_AVX2 },
 		{ ZIMG_CPU_X86_AVX512F,    CPUClass::X86_AVX2 },
-		{ ZIMG_CPU_X86_AVX512_SKL, CPUClass::X86_AVX512 },
+		{ ZIMG_CPU_X86_AVX512_SKX, CPUClass::X86_AVX512 },
 #endif
 	};
 	return search_enum_map(map, cpu, "unrecognized cpu type");
@@ -202,20 +202,17 @@ std::pair<zimg::graph::GraphBuilder::ChromaLocationW, zimg::graph::GraphBuilder:
 	typedef zimg::graph::GraphBuilder::ChromaLocationW ChromaLocationW;
 	typedef zimg::graph::GraphBuilder::ChromaLocationH ChromaLocationH;
 
-	// VS 2017 miscompiles this.
-#ifdef _MSC_VER
-	static const zimg::static_map<zimg_chroma_location_e, std::pair<ChromaLocationW, ChromaLocationH>, 6> map{
-#else
 	// Workaround for std::pair assignment operator missing constexpr.
 	struct chroma_pair {
 		ChromaLocationW first;
 		ChromaLocationH second;
-
+#ifdef _MSC_VER
+		char _[16 - sizeof(ChromaLocationW) - sizeof(ChromaLocationH) - sizeof(zimg_chroma_location_e)];
+#endif
 		operator std::pair<ChromaLocationW, ChromaLocationH>() const { return{ first, second }; }
 	};
 
 	static SM_CONSTEXPR_14 const zimg::static_map<zimg_chroma_location_e, chroma_pair, 6> map{
-#endif
 		{ ZIMG_CHROMA_LEFT,        { ChromaLocationW::LEFT,   ChromaLocationH::CENTER } },
 		{ ZIMG_CHROMA_CENTER,      { ChromaLocationW::CENTER, ChromaLocationH::CENTER } },
 		{ ZIMG_CHROMA_TOP_LEFT,    { ChromaLocationW::LEFT,   ChromaLocationH::TOP } },
@@ -318,15 +315,15 @@ std::unique_ptr<zimg::resize::Filter> translate_resize_filter(zimg_resample_filt
 		case ZIMG_RESIZE_BILINEAR:
 			return ztd::make_unique<zimg::resize::BilinearFilter>();
 		case ZIMG_RESIZE_BICUBIC:
-			param_a = std::isnan(param_a) ? 1.0 / 3.0 : param_a;
-			param_b = std::isnan(param_b) ? 1.0 / 3.0 : param_b;
+			param_a = std::isnan(param_a) ? zimg::resize::BicubicFilter::DEFAULT_B : param_a;
+			param_b = std::isnan(param_b) ? zimg::resize::BicubicFilter::DEFAULT_C : param_b;
 			return ztd::make_unique<zimg::resize::BicubicFilter>(param_a, param_b);
 		case ZIMG_RESIZE_SPLINE16:
 			return ztd::make_unique<zimg::resize::Spline16Filter>();
 		case ZIMG_RESIZE_SPLINE36:
 			return ztd::make_unique<zimg::resize::Spline36Filter>();
 		case ZIMG_RESIZE_LANCZOS:
-			param_a = std::isnan(param_a) ? 3.0 : std::floor(param_a);
+			param_a = std::isnan(param_a) ? zimg::resize::LanczosFilter::DEFAULT_TAPS : std::max(param_a, 1.0);
 			return ztd::make_unique<zimg::resize::LanczosFilter>(static_cast<unsigned>(param_a));
 		default:
 			zimg::error::throw_<zimg::error::EnumOutOfRange>("unrecognized resampling filter");
